1.5
===

Clean up syntax, configure automatic releases.

1.4
===

Moved hosting to Github.

1.3
===

Add ``.iterate`` to progress bars.

1.2.2
=====

Use ``jaraco.classes`` instead of ``jaraco.meta``, the latter of which was
never released.

1.2.1
=====

Add missing dependency on six.

1.2
===

Adopt ``cmdline`` module from ``jaraco.util``.

1.1
===

Prefer hgtools until setuptools_scm supports older setuptools versions.

1.0
===

Initial release drawn from jaraco.util 10.9.
